RetainPixelConfig class

Configuration for the RetainPixel client.

Constructors

RetainPixelConfig({required String orgId, required String appId, required String apiKey, String environment = 'live', String endpoint = 'https://ingest.retainpixel.com', int maxBufferSize = 20, Duration? flushInterval = const Duration(seconds: 30)})
const

Properties

apiKey String
API key from the RetainPixel dashboard.
final
appId String
App ID (UUID from RetainPixel dashboard).
final
endpoint String
Ingest endpoint. Defaults to production.
final
environment String
Environment: "test" or "live".
final
flushInterval Duration?
Auto-flush interval. Null disables periodic flushing.
final
hashCode int
The hash code for this object.
no setterinherited
maxBufferSize int
Maximum events to buffer before auto-flushing.
final
orgId String
Organization ID (UUID from RetainPixel dashboard).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited